@@ -236,7 +236,7 @@ def formstr_to_formdict(form_str:str):
 
     return form_dict
 
-def formdict_to_formstr(form_dict:dict):
+def formdict_to_formstr(form_dict:dict, include_one:bool=False):
     """
     Converts dictionary of {atomic label:quantity} pairs into a single formula string
 
@@ -244,7 +244,7 @@ def formdict_to_formstr(form_dict:dict):
         form_dict (dict) : dictionary of {atomic label:quantity} pairs
 
     Keyword arguments:
-        None
+        include_one (bool) : Include 1 in final chemical formula e.g. C1H4
 
     Returns:
         form_string (str) : Chemical formula as string
@@ -255,11 +255,13 @@ def formdict_to_formstr(form_dict:dict):
     form_quants = [val for val in form_dict.values()]
 
     # Quantities of each element as a string
-    # if only 1 of an element then use a blank string
-    # as this is how chemical formulae are written
-    form_quants_str = ["{:d}".format(quant) 
-                        if quant > 1 else "" 
-                        for quant in form_quants]
+    if include_one:
+        form_quants_str = ["{:d}".format(quant) 
+                           for quant in form_quants]
+    else:
+        form_quants_str = ["{:d}".format(quant) 
+                           if quant > 1 else "" 
+                           for quant in form_quants]
 
     # Sort labels in alphabetical order
     order = np.argsort(form_labels).tolist()
